@@ -6,7 +6,6 @@ use PhpAmqpLib\Exception\AMQPOutOfBoundsException;
 use PhpAmqpLib\Exception\AMQPOutOfRangeException;
 use PhpAmqpLib\Exception\AMQPRuntimeException;
 use PhpAmqpLib\Helper\DebugHelper;
-use PhpAmqpLib\Helper\MiscHelper;
 use PhpAmqpLib\Helper\Protocol\MethodMap080;
 use PhpAmqpLib\Helper\Protocol\MethodMap091;
 use PhpAmqpLib\Helper\Protocol\Protocol080;
@@ -70,7 +69,7 @@ abstract class AbstractChannel
 
     /**
      * @param AbstractConnection $connection
-     * @param $channel_id
+     * @param string $channel_id
      * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
      */
     public function __construct(AbstractConnection $connection, $channel_id)
@@ -111,7 +110,6 @@ abstract class AbstractChannel
                     'Protocol: %s not implemented.',
                     $this->protocolVersion
                 ));
-                break;
         }
     }
 
@@ -172,11 +170,11 @@ abstract class AbstractChannel
     /**
      * @param string $method_sig
      * @param string $args
-     * @param $content
+     * @param AMQPMessage|null $amqpMessage
      * @return mixed
      * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
      */
-    public function dispatch($method_sig, $args, $content)
+    public function dispatch($method_sig, $args, $amqpMessage)
     {
         if (!$this->methodMap->valid_method($method_sig)) {
             throw new AMQPRuntimeException(sprintf(
@@ -197,11 +195,11 @@ abstract class AbstractChannel
 
         $this->dispatch_reader->reuse($args);
 
-        if ($content == null) {
+        if ($amqpMessage == null) {
             return call_user_func(array($this, $amqp_method), $this->dispatch_reader);
         }
 
-        return call_user_func(array($this, $amqp_method), $this->dispatch_reader, $content);
+        return call_user_func(array($this, $amqp_method), $this->dispatch_reader, $amqpMessage);
     }
 
     /**
@@ -220,21 +218,25 @@ abstract class AbstractChannel
     }
 
     /**
-     * @param $method_sig
-     * @param string $args
+     * @param array $method_sig
+     * @param \PhpAmqpLib\Wire\AMQPWriter|string $args
      */
     protected function send_method_frame($method_sig, $args = '')
     {
+        if ($this->connection === null) {
+            throw new AMQPRuntimeException('Channel connection is closed.');
+        }
+
         $this->connection->send_channel_method_frame($this->channel_id, $method_sig, $args);
     }
 
     /**
      * This is here for performance reasons to batch calls to fwrite from basic.publish
      *
-     * @param $method_sig
-     * @param string $args
-     * @param null $pkt
-     * @return null|\PhpAmqpLib\Wire\AMQPWriter
+     * @param array $method_sig
+     * @param \PhpAmqpLib\Wire\AMQPWriter|string $args
+     * @param \PhpAmqpLib\Wire\AMQPWriter $pkt
+     * @return \PhpAmqpLib\Wire\AMQPWriter
      */
     protected function prepare_method_frame($method_sig, $args = '', $pkt = null)
     {
@@ -297,18 +299,6 @@ abstract class AbstractChannel
 
         $message->setBody(implode('', $bodyChunks));
 
-        $messageEncoding = $message->getContentEncoding();
-        
-        if ($this->auto_decode && !empty($messageEncoding)) {
-            try {
-                // Where does the decode() method come from if body is a string?
-                $decodedBody = $message->getBody()->decode($messageEncoding);
-                $message->setBody($decodedBody);
-            } catch (\Exception $e) {
-                $this->debug->debug_msg('Ignoring body decoding exception: ' . $e->getMessage());
-            }
-        }
-
         return $message;
     }
 
@@ -345,15 +335,15 @@ abstract class AbstractChannel
 
             $this->debug->debug_method_signature('> %s', $method_sig);
 
-            $content = $this->maybe_wait_for_content($method_sig);
+            $amqpMessage = $this->maybe_wait_for_content($method_sig);
 
             if ($this->should_dispatch_method($allowed_methods, $method_sig)) {
-                return $this->dispatch($method_sig, $args, $content);
+                return $this->dispatch($method_sig, $args, $amqpMessage);
             }
 
             // Wasn't what we were looking for? save it for later
             $this->debug->debug_method_signature('Queueing for later: %s', $method_sig);
-            $this->method_queue[] = array($method_sig, $args, $content);
+            $this->method_queue[] = array($method_sig, $args, $amqpMessage);
 
             if ($non_blocking) {
                 break;
@@ -361,6 +351,10 @@ abstract class AbstractChannel
         }
     }
 
+    /**
+     * @param array $allowed_methods
+     * @return array
+     */
     protected function process_deferred_methods($allowed_methods)
     {
         $dispatch = false;
@@ -382,6 +376,10 @@ abstract class AbstractChannel
         return array('dispatch' => $dispatch, 'queued_method' => $queued_method);
     }
 
+    /**
+     * @param array $queued_method
+     * @return mixed
+     */
     protected function dispatch_deferred_method($queued_method)
     {
         $this->debug->debug_method_signature('Executing queued method: %s', $queued_method[0]);
@@ -390,7 +388,7 @@ abstract class AbstractChannel
     }
 
     /**
-     * @param $frame_type
+     * @param int $frame_type
      * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
      */
     protected function validate_method_frame($frame_type)
@@ -398,31 +396,44 @@ abstract class AbstractChannel
         $this->validate_frame($frame_type, 1, 'AMQP method');
     }
 
+    /**
+     * @param int $frame_type
+     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
+     */
     protected function validate_header_frame($frame_type)
     {
         $this->validate_frame($frame_type, 2, 'AMQP Content header');
     }
 
+    /**
+     * @param int $frame_type
+     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
+     */
     protected function validate_body_frame($frame_type)
     {
         $this->validate_frame($frame_type, 3, 'AMQP Content body');
     }
 
-    protected function validate_frame($frame_type, $expected_type, $expected_msg)
+    /**
+     * @param int $frameType
+     * @param int $expectedType
+     * @param string $expectedMessage
+     */
+    protected function validate_frame($frameType, $expectedType, $expectedMessage)
     {
-        if ($frame_type != $expected_type) {
-            $PROTOCOL_CONSTANTS_CLASS = self::$PROTOCOL_CONSTANTS_CLASS;
+        if ($frameType != $expectedType) {
+            $protocolClass = self::$PROTOCOL_CONSTANTS_CLASS;
             throw new AMQPRuntimeException(sprintf(
-                'Expecting %s, received frame type %s (%s)',
-                $expected_msg,
-                $frame_type,
-                $PROTOCOL_CONSTANTS_CLASS::$FRAME_TYPES[$frame_type]
-            ));
+                    'Expecting %s, received frame type %s (%s)',
+                    $expectedMessage,
+                    $frameType,
+                    $protocolClass::$FRAME_TYPES[$frameType]
+                ));
         }
     }
 
     /**
-     * @param $payload
+     * @param string $payload
      * @throws \PhpAmqpLib\Exception\AMQPOutOfBoundsException
      */
     protected function validate_frame_payload($payload)
@@ -432,6 +443,10 @@ abstract class AbstractChannel
         }
     }
 
+    /**
+     * @param string $payload
+     * @return string
+     */
     protected function build_method_signature($payload)
     {
         $method_sig_array = unpack('n2', mb_substr($payload, 0, 4, 'ASCII'));
@@ -439,34 +454,47 @@ abstract class AbstractChannel
         return sprintf('%s,%s', $method_sig_array[1], $method_sig_array[2]);
     }
 
+    /**
+     * @param string $payload
+     * @return string
+     */
     protected function extract_args($payload)
     {
         return mb_substr($payload, 4, mb_strlen($payload, 'ASCII') - 4, 'ASCII');
     }
 
+    /**
+     * @param array|null $allowed_methods
+     * @param string $method_sig
+     * @return bool
+     */
     protected function should_dispatch_method($allowed_methods, $method_sig)
     {
-        $PROTOCOL_CONSTANTS_CLASS = self::$PROTOCOL_CONSTANTS_CLASS;
+        $protocolClass = self::$PROTOCOL_CONSTANTS_CLASS;
 
         return $allowed_methods == null
             || in_array($method_sig, $allowed_methods)
-            || in_array($method_sig, $PROTOCOL_CONSTANTS_CLASS::$CLOSE_METHODS);
-    }
-
-    protected function maybe_wait_for_content($method_sig)
-    {
-        $PROTOCOL_CONSTANTS_CLASS = self::$PROTOCOL_CONSTANTS_CLASS;
-        $content = null;
-
-        if (in_array($method_sig, $PROTOCOL_CONSTANTS_CLASS::$CONTENT_METHODS)) {
-            $content = $this->wait_content();
-        }
-
-        return $content;
+            || in_array($method_sig, $protocolClass::$CLOSE_METHODS);
     }
 
     /**
-     * @param $handler
+     * @param string $method_sig
+     * @return AMQPMessage|null
+     */
+    protected function maybe_wait_for_content($method_sig)
+    {
+        $protocolClass = self::$PROTOCOL_CONSTANTS_CLASS;
+        $amqpMessage = null;
+
+        if (in_array($method_sig, $protocolClass::$CONTENT_METHODS)) {
+            $amqpMessage = $this->wait_content();
+        }
+
+        return $amqpMessage;
+    }
+
+    /**
+     * @param callable $handler
      * @param array $arguments
      */
     protected function dispatch_to_handler($handler, array $arguments)
