@@ -25,7 +25,7 @@ class AMQPException extends \Exception
     /**
      * @param string $reply_code
      * @param int $reply_text
-     * @param \Exception $method_sig
+     * @param array $method_sig
      */
     public function __construct($reply_code, $reply_text, $method_sig)
     {
@@ -36,9 +36,9 @@ class AMQPException extends \Exception
         $this->amqp_method_sig = $method_sig;
 
         $ms = MiscHelper::methodSig($method_sig);
-        $PROTOCOL_CONSTANTS_CLASS = AbstractChannel::$PROTOCOL_CONSTANTS_CLASS;
-        $mn = isset($PROTOCOL_CONSTANTS_CLASS::$GLOBAL_METHOD_NAMES[$ms])
-            ? $PROTOCOL_CONSTANTS_CLASS::$GLOBAL_METHOD_NAMES[$ms]
+        $protocolClass = AbstractChannel::$PROTOCOL_CONSTANTS_CLASS;
+        $mn = isset($protocolClass::$GLOBAL_METHOD_NAMES[$ms])
+            ? $protocolClass::$GLOBAL_METHOD_NAMES[$ms]
             : $mn = '';
 
         $this->args = array($reply_code, $reply_text, $method_sig, $mn);
