@@ -5,6 +5,7 @@ use PhpAmqpLib\Exception\AMQPInvalidArgumentException;
 use PhpAmqpLib\Exception\AMQPOutOfBoundsException;
 use PhpAmqpLib\Exception\AMQPRuntimeException;
 use PhpAmqpLib\Exception\AMQPTimeoutException;
+use PhpAmqpLib\Exception\AMQPIOWaitException;
 use PhpAmqpLib\Helper\MiscHelper;
 use PhpAmqpLib\Wire\IO\AbstractIO;
 
@@ -95,7 +96,7 @@ class AMQPReader extends AbstractClient
     }
 
     /**
-     * @param $n
+     * @param int $n
      * @return string
      */
     public function read($n)
@@ -110,6 +111,7 @@ class AMQPReader extends AbstractClient
      *
      * AMQPTimeoutException can be raised if the timeout is set
      *
+     * @throws \PhpAmqpLib\Exception\AMQPIOWaitException
      * @throws \PhpAmqpLib\Exception\AMQPTimeoutException
      */
     protected function wait()
@@ -123,7 +125,7 @@ class AMQPReader extends AbstractClient
         $result = $this->io->select($sec, $usec);
 
         if ($result === false) {
-            throw new AMQPRuntimeException('A network error occured while awaiting for incoming data');
+            throw new AMQPIOWaitException('A network error occured while awaiting for incoming data');
         }
 
         if ($result === 0) {
@@ -135,7 +137,7 @@ class AMQPReader extends AbstractClient
     }
 
     /**
-     * @param $n
+     * @param int $n
      * @return string
      * @throws \RuntimeException
      * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
@@ -146,21 +148,23 @@ class AMQPReader extends AbstractClient
             $this->wait();
             $res = $this->io->read($n);
             $this->offset += $n;
-        } else {
-            if ($this->str_length < $n) {
-                throw new AMQPRuntimeException(sprintf(
-                    'Error reading data. Requested %s bytes while string buffer has only %s',
-                    $n,
-                    $this->str_length
-                ));
-            }
 
-            $res = mb_substr($this->str, 0, $n, 'ASCII');
-            $this->str = mb_substr($this->str, $n, mb_strlen($this->str, 'ASCII') - $n, 'ASCII');
-            $this->str_length -= $n;
-            $this->offset += $n;
+            return $res;
         }
 
+        if ($this->str_length < $n) {
+            throw new AMQPRuntimeException(sprintf(
+                'Error reading data. Requested %s bytes while string buffer has only %s',
+                $n,
+                $this->str_length
+            ));
+        }
+
+        $res = mb_substr($this->str, 0, $n, 'ASCII');
+        $this->str = mb_substr($this->str, $n, mb_strlen($this->str, 'ASCII') - $n, 'ASCII');
+        $this->str_length -= $n;
+        $this->offset += $n;
+
         return $res;
     }
 
@@ -443,7 +447,6 @@ class AMQPReader extends AbstractClient
     public function read_value($fieldType, $collectionsAsObjects = false)
     {
         $this->bitcount = $this->bits = 0;
-        $val = null;
 
         switch ($fieldType) {
             case AMQPAbstractCollection::T_INT_SHORTSHORT:
@@ -505,7 +508,7 @@ class AMQPReader extends AbstractClient
                 ));
         }
 
-        return $val;
+        return isset($val) ? $val : null;
     }
 
     /**
@@ -519,7 +522,7 @@ class AMQPReader extends AbstractClient
     /**
      * Sets the timeout (second)
      *
-     * @param $timeout
+     * @param int $timeout
      */
     public function setTimeout($timeout)
     {
